# - Config file for the Dakota package
# It defines the following variables
#  Dakota_INCLUDE_DIRS - include directories for Dakota
#  Dakota_LIBRARIES    - libraries to link against
#  Dakota_EXECUTABLE   - the dakota executable

# Compute paths
get_filename_component(DAKOTA_CMAKE_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)

# Check existence since may be building/installing under
# Trilinos/TriKota, or using an external Trilinos
if (EXISTS "${CMAKE_CURRENT_LIST_DIR}/../Teuchos/TeuchosConfig.cmake")
  include("${CMAKE_CURRENT_LIST_DIR}/../Teuchos/TeuchosConfig.cmake")
endif()

# Conservative approach for now
if (EXISTS "${CMAKE_CURRENT_LIST_DIR}/../../../share/eigen3/cmake")
  set(Eigen3_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../share/eigen3/cmake")
endif()
include(CMakeFindDependencyMacro)
find_dependency(Eigen3)

# Our library dependencies (contains definitions for IMPORTED targets)
include("${DAKOTA_CMAKE_DIR}/DakotaTargets.cmake")


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was DakotaConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib64/cmake/dakota" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

# Build tree option not yet working
if (Dakota_BUILD_TREE)
  # Dakota's build tree doesn't have a single convenient place for headers
  set(Dakota_INCLUDE_DIRS_TMP "/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/generated/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/packages/external/trilinos;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/teuchos/remainder/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/packages/external/trilinos/packages/teuchos/remainder/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/packages/external/trilinos/packages/teuchos/core/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/teuchos/core/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/teuchos/numerics/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/teuchos/comm/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/teuchos/parameterlist/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/teuchos/parser/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/packages/pecos;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/pecos/util/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/pecos/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/VPISparseGrid/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/packages/surfpack;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/surfpack/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/src/util;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/src/surrogates;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/eigen3/include/eigen3;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/packages/external/acro/packages;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/packages/external/acro/packages/utilib;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/acro/packages/interfaces/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/acro/packages/scolib/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/acro/packages/utilib/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/acro/packages/colin/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/acro/packages/pebbl/src/bb;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/acro/packages/pebbl/src/comm;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/acro/packages/pebbl/src/misc;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/acro/packages/pebbl/src/pbb;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/acro/packages/pebbl/src/sched;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/acro/tpl/tinyxml;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/approxnn/include;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/packages/external/DDACE;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/DDACE/include;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/dream;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/packages/external/FSUDace;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/FSUDace;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/packages/external/hopspack/src/src-shared;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/hopspack/src/src-shared;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/hopspack/src/src-citizens;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/hopspack/src/src-evaluator;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/hopspack/src/src-executor;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/hopspack/src/src-framework;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/hopspack/src/src-main;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/packages/external/JEGA;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/packages/external/JEGA/eddy;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/JEGA/eddy;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/JEGA/include;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/packages/external/NOMAD/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/NOMAD/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/packages/external/OPTPP/include;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/OPTPP/include;/usr/include/eigen3;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/packages/external/trilinos;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/packages/external/trilinos/packages/rol/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/compatibility/teuchos/rcp;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/compatibility/teuchos/parameterlist;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/compatibility/teuchos/stacktrace;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/compatibility/teuchos/la;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/compatibility/teuchos/lapack;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/vector;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/function;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/function/dynamic;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/function/boundconstraint;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/function/constraint;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/function/nlls;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/function/objective;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/function/operator;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/function/simopt;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/function/sketching;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/function/std;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/step;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/step/linesearch;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/step/trustregion;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/step/secant;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/step/krylov;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/step/bundle;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/step/augmentedlagrangian;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/step/moreauyosidapenalty;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/step/interiorpoint;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/step/nonlinearcg;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/step/fletcher;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/algorithm;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/status;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/sol;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/sol/function;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/sol/function/distribution;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/sol/function/expectationquad;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/risk;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/risk/fdivergence;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/risk/spectral;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/error;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/regret;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/deviation;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/probability;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/sol/function/progressivehedging;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/sol/algorithm;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/sol/vector;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/sol/sampler;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/sol/sampler/SROM;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/sol/status;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/elementwise;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/utils;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/utils/function_bindings;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/zoo;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/rol/src/zoo/testproblems;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/teuchos/remainder/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/packages/external/trilinos/packages/teuchos/remainder/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/packages/external/trilinos/packages/teuchos/core/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/teuchos/core/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/teuchos/numerics/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/teuchos/comm/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/teuchos/parameterlist/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/trilinos/packages/teuchos/parser/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/packages/external/PSUADE;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/packages/external/ampl")
  # This won't work yet.  Since Dakota is in a build tree the
  # libraries are scattered, but the import doesn't know where they
  # are.
  set(Dakota_LIBRARY_DIRS_TMP "/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/packages/external/trilinos/packages/teuchos/remainder/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/packages/external/trilinos/packages/teuchos/core/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/packages/external/trilinos/packages/teuchos/numerics/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/packages/external/trilinos/packages/teuchos/comm/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/packages/external/trilinos/packages/teuchos/parameterlist/src;/home/abuild/rpmbuild/BUILD/dakota-6.12.0.src/build/packages/external/trilinos/packages/teuchos/parser/src")
else()
  set_and_check(Dakota_INCLUDE_DIRS_TMP "${PACKAGE_PREFIX_DIR}/include")
  set_and_check(Dakota_LIB_DIRS_TMP "${PACKAGE_PREFIX_DIR}/lib")
endif()

# Variables intended for use by other projects

set_and_check(Dakota_DIR ${DAKOTA_CMAKE_DIR})

# TODO: reference in src vs bin
set(Dakota_EXECUTABLE dakota)


set(Dakota_DEFINES "HAVE_CONFIG_H;HAVE_DAKOTA_SURROGATES;HAVE_CONFIG_H;DISABLE_DAKOTA_CONFIG_H;BOOST_DISABLE_ASSERTS;HAVE_UNISTD_H;HAVE_SYSTEM;HAVE_WORKING_FORK;HAVE_WORKING_VFORK;HAVE_SYS_WAIT_H;HAVE_USLEEP;DAKOTA_F90;DAKOTA_PYTHON;HAVE_;HAVE_SURFPACK;HAVE_DAKOTA_SURROGATES;HAVE_ACRO;DAKOTA_UTILIB;HAVE_APPROXNN;HAVE_ADAPTIVE_SAMPLING;HAVE_CONMIN;HAVE_DDACE;HAVE_DREAM;HAVE_FSUDACE;DAKOTA_HOPS;HAVE_JEGA;HAVE_NCSU;HAVE_NL2SOL;HAVE_NOMAD;HAVE_OPTPP;DAKOTA_OPTPP;HAVE_ROL;HAVE_PSUADE;HAVE_AMPL")

set(Dakota_INCLUDE_DIRS ${Dakota_INCLUDE_DIRS_TMP})

set(Dakota_LIBRARY_DIRS ${Dakota_LIB_DIRS_TMP})

# These are IMPORTED targets created by DakotaTargets.cmake
set(Dakota_LIBRARIES "dakota_surrogates;dakota_util;dakota_src;dakota_src_fortran;nidr;teuchosremainder;teuchosnumerics;teuchoscomm;teuchosparameterlist;teuchosparser;teuchoscore;pecos_util;pecos_src;lhs;lhs_mods;lhs_mod;dfftpack;sparsegrid;surfpack;surfpack;surfpack_fortran;utilib;colin;interfaces;scolib;3po;pebbl;tinyxml;approxnn;conmin;ddace;dream;fsudace;hopspack;jega;jega_fe;moga;soga;eutils;utilities;ncsuopt;cport;nomad;optpp;psuade;amplsolver")

# Not built in Dakota's CMake process
set(Dakota_EXTPROJ_LIBRARIES "")

# TPLs external to the build
set(Dakota_TPL_INCLUDE_DIRS "/usr/include;/usr/include;/usr/include/python3.6m")

set(Dakota_TPL_LIBRARY_DIRS "/usr/lib64")

set(Dakota_TPL_LIBRARIES "/usr/lib64/libpython3.6m.so;/usr/lib64/libboost_filesystem.so;/usr/lib64/libboost_program_options.so;/usr/lib64/libboost_regex.so;/usr/lib64/libboost_serialization.so;/usr/lib64/libboost_system.so;/usr/lib64/liblapack.so;/usr/lib64/libblas.so")
